Errors = {
        400: "BAD_REQUEST_BODY",
        401: "UNAUTHORIZED",
        403: "ACCESS_DENIED",
        404: "NotFoundError",
        406: "NotAcceptableError",
        409: "ConflictError",
        415: "UnsupportedMediaTypeError",
        422: "UnprocessableEntityError",
        429: "TooManyRequestsError",
        500: "API_CONFIGURATION_ERROR",
        502: "BadGatewayError",
        503: "ServiceUnavailableError",
        504: "GatewayTimeoutError"
    }