import setuptools
from setuptools import setup, find_packages
from codecs import open
from os import path

setup(
    name='silasdk',


    version='0.2.13.rc',

    description='Sila Python library for message signing and api wrapper',

    url="https://github.com/Sila-Money/Sila-Python",

    author='Sila',
    author_email='support@silamoney.com',

    license='Apache',

    classifiers=[
        
        # How stable is your project? 
        #   3 - Alpha, 4 - Beta,5 - Production/Stable

        'Development Status :: 4 - Beta',

        'Intended Audience :: Developers',

        'License :: OSI Approved :: MIT License',

        'Programming Language :: Python :: 3.6'

    ],

    keywords='Sila v0.2.13.rc Rest API',

    packages=["silasdk"],

    install_requires=["requests>=2.20.0","pyaml>=15.8.2","eth-account==0.3.0","uuid==1.30","pysha3==1.0.2"],

    zip_safe=False,
    
    include_package_data=True,

    extras_require={},

   
    package_data={},

  
    entry_points={}
)